<?php

namespace Litecms\CategoriesDetail\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\CategoriesDetail\Http\Requests\CategoriesDetailsRequest;
use Litecms\CategoriesDetail\Interfaces\CategoriesDetailsRepositoryInterface;
use Litecms\CategoriesDetail\Models\CategoriesDetails;

/**
 * Resource controller class for categories_details.
 */
class CategoriesDetailsResourceController extends BaseController
{

    /**
     * Initialize categories_details resource controller.
     *
     * @param type CategoriesDetailsRepositoryInterface $categories_details
     *
     * @return null
     */
    public function __construct(CategoriesDetailsRepositoryInterface $categories_details)
    {
        parent::__construct();
        $this->repository = $categories_details;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\CategoriesDetail\Repositories\Criteria\CategoriesDetailsResourceCriteria::class);
    }

    /**
     * Display a list of categories_details.
     *
     * @return Response
     */
    public function index(CategoriesDetailsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\CategoriesDetail\Repositories\Presenter\CategoriesDetailsPresenter::class)
                ->$function();
        }

        $categories_details = $this->repository->paginate();

        return $this->response->title(trans('categories_detail::categories_details.names'))
            ->view('categories_detail::categories_details.index', true)
            ->data(compact('categories_details'))
            ->output();
    }

    /**
     * Display categories_details.
     *
     * @param Request $request
     * @param Model   $categories_details
     *
     * @return Response
     */
    public function show(CategoriesDetailsRequest $request, CategoriesDetails $categories_details)
    {

        if ($categories_details->exists) {
            $view = 'categories_detail::categories_details.show';
        } else {
            $view = 'categories_detail::categories_details.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('categories_detail::categories_details.name'))
            ->data(compact('categories_details'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new categories_details.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CategoriesDetailsRequest $request)
    {

        $categories_details = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('categories_detail::categories_details.name')) 
            ->view('categories_detail::categories_details.create', true) 
            ->data(compact('categories_details'))
            ->output();
    }

    /**
     * Create new categories_details.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CategoriesDetailsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $categories_details                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('categories_detail::categories_details.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('categories_detail/categories_details/' . $categories_details->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/categories_detail/categories_details'))
                ->redirect();
        }

    }

    /**
     * Show categories_details for editing.
     *
     * @param Request $request
     * @param Model   $categories_details
     *
     * @return Response
     */
    public function edit(CategoriesDetailsRequest $request, CategoriesDetails $categories_details)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('categories_detail::categories_details.name'))
            ->view('categories_detail::categories_details.edit', true)
            ->data(compact('categories_details'))
            ->output();
    }

    /**
     * Update the categories_details.
     *
     * @param Request $request
     * @param Model   $categories_details
     *
     * @return Response
     */
    public function update(CategoriesDetailsRequest $request, CategoriesDetails $categories_details)
    {
        try {
            $attributes = $request->all();

            $categories_details->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('categories_detail::categories_details.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('categories_detail/categories_details/' . $categories_details->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('categories_detail/categories_details/' . $categories_details->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the categories_details.
     *
     * @param Model   $categories_details
     *
     * @return Response
     */
    public function destroy(CategoriesDetailsRequest $request, CategoriesDetails $categories_details)
    {
        try {

            $categories_details->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('categories_detail::categories_details.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('categories_detail/categories_details/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('categories_detail/categories_details/' . $categories_details->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple categories_details.
     *
     * @param Model   $categories_details
     *
     * @return Response
     */
    public function delete(CategoriesDetailsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('categories_detail::categories_details.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('categories_detail/categories_details'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/categories_detail/categories_details'))
                ->redirect();
        }

    }

    /**
     * Restore deleted categories_details.
     *
     * @param Model   $categories_details
     *
     * @return Response
     */
    public function restore(CategoriesDetailsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('categories_detail::categories_details.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/categories_detail/categories_details'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/categories_detail/categories_details/'))
                ->redirect();
        }

    }

}
