<?php

namespace Litecms\CategoriesDetail\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\CategoriesDetail\Models\CategoriesDetails;

class CategoriesDetailsPolicy
{

    /**
     * Determine if the given user can view the categories_details.
     *
     * @param UserPolicy $user
     * @param CategoriesDetails $categories_details
     *
     * @return bool
     */
    public function view(UserPolicy $user, CategoriesDetails $categories_details)
    {
        if ($user->canDo('categories_detail.categories_details.view') && $user->isAdmin()) {
            return true;
        }

        return $categories_details->user_id == user_id() && $categories_details->user_type == user_type();
    }

    /**
     * Determine if the given user can create a categories_details.
     *
     * @param UserPolicy $user
     * @param CategoriesDetails $categories_details
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('categories_detail.categories_details.create');
    }

    /**
     * Determine if the given user can update the given categories_details.
     *
     * @param UserPolicy $user
     * @param CategoriesDetails $categories_details
     *
     * @return bool
     */
    public function update(UserPolicy $user, CategoriesDetails $categories_details)
    {
        if ($user->canDo('categories_detail.categories_details.edit') && $user->isAdmin()) {
            return true;
        }

        return $categories_details->user_id == user_id() && $categories_details->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given categories_details.
     *
     * @param UserPolicy $user
     * @param CategoriesDetails $categories_details
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CategoriesDetails $categories_details)
    {
        return $categories_details->user_id == user_id() && $categories_details->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given categories_details.
     *
     * @param UserPolicy $user
     * @param CategoriesDetails $categories_details
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CategoriesDetails $categories_details)
    {
        if ($user->canDo('categories_detail.categories_details.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given categories_details.
     *
     * @param UserPolicy $user
     * @param CategoriesDetails $categories_details
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CategoriesDetails $categories_details)
    {
        if ($user->canDo('categories_detail.categories_details.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
